@@ -27,22 +27,24 @@
 
 #include "INLAtools.h"
 
-double *inla_cgeneric_generic0(inla_cgeneric_cmd_tp cmd, double *theta, inla_cgeneric_data_tp *data)
+double *inla_cgeneric_generic0(inla_cgeneric_cmd_tp cmd, double *theta,
+			       inla_cgeneric_data_tp *data)
 {
 
 	// Q = \tau*R
 
 	double *ret = NULL, prec;
 
-	assert(!strcasecmp(data->ints[0]->name, "n"));	       // this will always be the case
-	int N = data->ints[0]->ints[0];			       // this will always be the case
+	assert(!strcasecmp(data->ints[0]->name, "n"));	// this will always be the case
+	int N = data->ints[0]->ints[0];	// this will always be the case
 	assert(N > 0);
 
-	assert(!strcasecmp(data->ints[1]->name, "debug"));     // this will always be the case
-//	int debug = data->ints[1]->ints[0];
+	assert(!strcasecmp(data->ints[1]->name, "debug"));	// this will always be the case
+//      int debug = data->ints[1]->ints[0];
 
 	int fixed = 1;
-	if ((data->doubles[0]->doubles[1] > 0) & (data->doubles[0]->doubles[1] < 1)) {
+	if ((data->doubles[0]->doubles[1] > 0) & (data->doubles[0]->doubles[1] <
+						  1)) {
 		fixed = 0;
 	}
 
@@ -64,106 +66,109 @@ double *inla_cgeneric_generic0(inla_cgeneric_cmd_tp cmd, double *theta, inla_cge
 	assert(N == Rgraph->ncol);
 	int M = Rgraph->n;
 	/*
-	if (debug > 99) {
-		printf("M = %d\n", M);
-	}
-	*/
+	   if (debug > 99) {
+	   printf("M = %d\n", M);
+	   }
+	 */
 
 	switch (cmd) {
 
 	case INLA_CGENERIC_VOID:
-	{
-		assert(!(cmd == INLA_CGENERIC_VOID));
-		break;
-	}
+		{
+			assert(!(cmd == INLA_CGENERIC_VOID));
+			break;
+		}
 
 	case INLA_CGENERIC_GRAPH:
-	{
-		int offset = 2;
-		ret = Calloc(2 + 2 * M, double);
-		ret[0] = N;				       /* dimension */
-		ret[1] = M;				       /* number of (i <= j) */
-		for (int k = 0; k < M; k++) {
-			ret[offset + k] = Rgraph->i[k];
-			ret[offset + M + k] = Rgraph->j[k];
+		{
+			int offset = 2;
+			ret = Calloc(2 + 2 * M, double);
+			ret[0] = N;	/* dimension */
+			ret[1] = M;	/* number of (i <= j) */
+			for (int k = 0; k < M; k++) {
+				ret[offset + k] = Rgraph->i[k];
+				ret[offset + M + k] = Rgraph->j[k];
+			}
+			break;
 		}
-		break;
-	}
 
 	case INLA_CGENERIC_Q:
-	{
-		int offset = 2;
-		ret = Calloc(2 + M, double);
-		ret[0] = -1;				       /* REQUIRED */
-		ret[1] = M;
-		for (int k = 0; k < M; k++) {
-			ret[offset + k] = prec * Rgraph->x[k];
+		{
+			int offset = 2;
+			ret = Calloc(2 + M, double);
+			ret[0] = -1;	/* REQUIRED */
+			ret[1] = M;
+			for (int k = 0; k < M; k++) {
+				ret[offset + k] = prec * Rgraph->x[k];
+			}
+			break;
 		}
-		break;
-	}
 
 	case INLA_CGENERIC_MU:
-	{
-		// return (N, mu)
-		// if N==0 then mu is not needed as its taken to be mu[]==0
-		ret = Calloc(1, double);
-		ret[0] = 0;
-		break;
-	}
-
-	case INLA_CGENERIC_INITIAL:
-	{
-		// return c(M, initials)
-		// where M is the number of hyperparameters
-		if (fixed) {
+		{
+			// return (N, mu)
+			// if N==0 then mu is not needed as its taken to be mu[]==0
 			ret = Calloc(1, double);
 			ret[0] = 0;
-		} else {
-			ret = Calloc(2, double);
-			ret[0] = 1;
-			ret[1] = 0.0;
+			break;
+		}
+
+	case INLA_CGENERIC_INITIAL:
+		{
+			// return c(M, initials)
+			// where M is the number of hyperparameters
+			if (fixed) {
+				ret = Calloc(1, double);
+				ret[0] = 0;
+			} else {
+				ret = Calloc(2, double);
+				ret[0] = 1;
+				ret[1] = 0.0;
+			}
+			break;
 		}
-		break;
-	}
 
 	case INLA_CGENERIC_LOG_NORM_CONST:
-	{
-		break;
-	}
+		{
+			break;
+		}
 
 	case INLA_CGENERIC_LOG_PRIOR:
-	{
-		// return c(LOG_PRIOR), PC-PREC
-		ret = Calloc(1, double);
-		if (fixed) {
-			ret[0] = 0.0;
-		} else {
-			double val = 0.5 * theta[0];
-			assert(!strcasecmp(data->doubles[0]->name, "param"));
-			double u = data->doubles[0]->doubles[0];
-			double a = data->doubles[0]->doubles[1];
-			double l = -log(a) / u;
+		{
+			// return c(LOG_PRIOR), PC-PREC
+			ret = Calloc(1, double);
+			if (fixed) {
+				ret[0] = 0.0;
+			} else {
+				double val = 0.5 * theta[0];
+				assert(!strcasecmp
+				       (data->doubles[0]->name, "param"));
+				double u = data->doubles[0]->doubles[0];
+				double a = data->doubles[0]->doubles[1];
+				double l = -log(a) / u;
 /*
  			if (debug > 99) {
 				printf("th %f, u %f, a %f and l %f\n", theta[0], u, a, l);
 			}
 */
-			if (u <= 0) {
-				ret[0] = 0.0;
-			} else {
-				if (a <= 0.0) {
+				if (u <= 0) {
 					ret[0] = 0.0;
 				} else {
-					if (a >= 1.0) {
+					if (a <= 0.0) {
 						ret[0] = 0.0;
 					} else {
-						ret[0] = log(0.5 * l) - l * exp(-val) - val;
+						if (a >= 1.0) {
+							ret[0] = 0.0;
+						} else {
+							ret[0] =
+							    log(0.5 * l) -
+							    l * exp(-val) - val;
+						}
 					}
 				}
 			}
+			break;
 		}
-		break;
-	}
 
 	case INLA_CGENERIC_QUIT:
 	default:
